#[non_exhaustive]pub enum IntersectionError {
TooManyPatterns,
}Expand description
Why an exact pattern intersection could not be represented safely.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TooManyPatterns
The exact intersection would contain too many distinct patterns.